/*
 * POV-Ray file to generate the gwy_fit_shape icon
 * Franois Riguet (Francheu)
 * E-mail: francheu@gwyddion.net
 * Version 1.0 (January 2017)
 * Render with the following options: +d +W24 +H24 +X +A0.3 +UA
*/

#version 3.7;
global_settings {assumed_gamma 1.2} 

#declare sphere_texture =  
texture {
    pigment {color rgb <0.3, 0.1, 0.5>}
    finish {
        ambient 0.35
        brilliance 2
        diffuse 0.3
        metallic
        specular 0.80
        roughness 1/20
        reflection 0.1
    }
}
     
camera {
   location <-5, 10, -15>
   angle 10
   look_at <0.05, -0.07, 0>
   up <0, 1, 0> 
   right <1, 0, 0>
}

#declare dist=80.0;
light_source {<-50, 50, -50> color rgb <1, 1, 1> fade_distance dist fade_power 2}
light_source {<-50, 50, -40> color rgb <1, 1, 1> fade_distance dist fade_power 2}

#declare func = function(x, y) {pow(x, 3)/2+pow(y, 3)/2-0.2*(x+y)}

#declare increment=1;
#for (i1, -1, 1, increment)
    #for (i2, -1, 1, increment) 
         sphere {
            <i1, func(i1, i2)*1.2, i2>, 0.3
            texture {sphere_texture} 
            no_shadow 
            no_reflection
         }
    #end
#end

isosurface {
  function{y-func(x, z)}
  threshold 0
  contained_by {box {<-1, -1, -1>, <1, 1, 1>}}
  accuracy 0.0001
  max_gradient 3
  open
  pigment {
      gradient y
      color_map {
        [0.0 color rgb <0,   0, 1>]
        [0.2 color rgb <0, 0.1, 1>]
        [0.5 color rgb <0,   1, 0>]
        [0.8 color rgb <1, 0.1, 0>]
        [1.0 color rgb <1,   0, 0>]
      }
      scale 1.2
      translate y*-0.6 
  }
} 
